<?php
/**
 * Gestion du formulaire de d'édition d'une subdivision
 *
 * @plugin     Subdivisions Géographiques
 * @copyright  2020
 * @author     Vincent CALLIES
 * @licence    GNU/GPL
 * @package    SPIP\Subdivisions\Formulaires
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

include_spip('inc/actions');
include_spip('inc/editer');

/**
 * Un simple formulaire de déclaration des saisies
 *
 * Utilisation du plugin Saisies
 *
 * @return array
 *     tableau décrivant les saisies à afficher dans le formulaire de configuration
 **/
 
function formulaires_subdivision_saisies($pays){
	$saisies = array(
       array( 
          'saisie' => 'hidden',
          'options' => array(
            'nom' => 'id_subdivision',
           )
      ),
       array( 
          'saisie' => 'hidden',
          'options' => array(
            'nom' => 'retour',
           )
      ),
      array( 
          'saisie' => 'textarea',
          'options' => array(
            'nom' => 'titre',
            'label' => _T('subdivision:label_titre_edition'),
 			'obligatoire' => 'oui',
 			'conteneur_class' => 'pleine_largeur',
 			//'inserer_barre' => 'non',
			//'previsualisation' => 'non',
         ),
     ),
		array(
			'saisie' => 'input',
			'options' => array(
				'nom' => 'nom_usage',
				'conteneur_class' => 'pleine_largeur',
 				'label' => _T('subdivision:label_nom_usage'),
				'explication' => _T('subdivision:label_nom_usage_explication'),
			),
		),
		array(
			'saisie' => 'input',
			'options' => array(
				'nom' => 'iso_moi',
				'label' => _T('subdivision:label_iso_moi'),
				'explication' => _T('subdivision:label_iso_moi_explication'),
			),
		),
		array(
			'saisie' => 'input',
			'options' => array(
				'nom' => 'specifique',
				'label' => _T('subdivision:label_specifique'),
				'explication' => _T('subdivision:label_specifique_explication'),
			),
		),
		array(
			'saisie' => 'input',
			'options' => array(
				'nom' => 'iso_parent',
				'label' => _T('subdivision:label_iso_parent'),
				'explication' => _T('subdivision:label_iso_parent_explication'),
			),
		),
		array(
			'saisie' => 'input',
			'options' => array(
				'nom' => 'iso_pays',
				'label' => _T('subdivision:label_iso_pays'),
				'explication' => _T('subdivision:label_iso_pays_explication'),
			),
		),
		array(
			'saisie' => 'input',
			'options' => array(
				'nom' => 'nuts',
				'label' => _T('subdivision:label_nuts'),
				'explication' => _T('subdivision:label_nuts_explication'),
			),
		),
	);
	return $saisies;
}

/**
 * Identifier le formulaire en faisant abstraction des paramètres qui ne représentent pas l'objet édité
 *
 * @param int|string $id_subdivision
 *     Identifiant de la subdivision. 'new' pour une nouvelle subdivision.
 * @param int $id_parent
 *     Identifiant de l'objet parent (si connu) - ici inutile
 * @param string $retour
 *     URL de redirection après le traitement
 * @param int $lier_trad
 *     Identifiant éventuel d'une nouvelle subdivision source d'une traduction (inutile nous sommes en multi)
 * @param string $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array $row
 *     Valeurs de la ligne SQL du paiement, si connu
 * @param string $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 * @return string
 *     Hash du formulaire
 */
function formulaires_editer_subdivision_identifier_dist($id_subdivision = 'new', $id_pays = 0, $retour = '', $lier_trad = 0, $config_fonc = '', $row = array(), $hidden = '') {
	return serialize(array(intval($id_subdivision)));
}

/**
 * Chargement du formulaire d'édition de subdivision
 *
 * Déclarer les champs postés et y intégrer les valeurs par défaut
 *
 * @uses formulaires_editer_objet_charger()
 *
 * @param int|string $id_subdivision
 *     Identifiant de la subdivision. 'new' pour une nouvelle subdivision.
 * @param int $id_parent
 *     Identifiant de l'objet parent (si connu) - ici inutile
 * @param string $retour
 *     URL de redirection après le traitement
 * @param int $lier_trad
 *     Identifiant éventuel d'une nouvelle subdivision source d'une traduction (inutile nous sommes en multi)
 * @param string $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array $row
 *     Valeurs de la ligne SQL du paiement, si connu
 * @param string $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 * @return array
 *     Environnement du formulaire
 */
function formulaires_editer_subdivision_charger_dist($id_subdivision = 'new', $id_parent = 0, $retour = '', $lier_trad = 0, $config_fonc = '', $row = array(), $hidden = '') {
	$valeurs = formulaires_editer_objet_charger('subdivision', $id_subdivision, $id_parent, $lier_trad, $retour, $config_fonc, $row, $hidden);
	if (!$valeurs['id_subdivision']) {
		$valeurs['id_subdivision'] = $id_subdivision;
	}
	$valeurs['retour'] = $retour;

	// selon l'existence du plugin Pays et de sa saisie, nourrir la déclaration des saisies.

	if (test_plugin_actif('pays')) {
		$pays =	array(
			'saisie' => 'pays',
			'options' => array(
				'nom' => 'iso_pays',
				'label' => _T('pays:titre_pays'),
				'cacher_option_intro' => 'oui',
				//'champ_pays' => 'id_pays'
			),
		);
	} else {
		$pays =	array(
			'saisie' => 'input',
			'options' => array(
				'nom' => 'iso_pays',
				'label' => _T('subdivision:label_iso_pays'),
				'explication' => _T('subdivision:label_iso_pays_explication'),
			),
		);
	}


	// transmettre les listes au plugin Saisies pour formulaires

	$valeurs['_mes_saisies'] = formulaires_subdivision_saisies($pays);
	
	return $valeurs;
}

/**
 * Vérifications du formulaire d'édition de subdivision
 *
 * Vérifier les champs postés et signaler d'éventuelles erreurs
 *
 * @uses formulaires_editer_objet_verifier()
 *
 * @param int|string $id_subdivision
 *     Identifiant de la subdivision. 'new' pour un nouveau paiement.
 * @param int $id_parent
 *     Identifiant de l'objet parent (si connu) - ici inutile
 * @param string $retour
 *     URL de redirection après le traitement
 * @param int $lier_trad
 *     Identifiant éventuel d'une nouvelle subdivision source d'une traduction (inutile nous sommes en multi)
 * @param string $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array $row
 *     Valeurs de la ligne SQL du paiement, si connu
 * @param string $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 * @return array
 *     Tableau des erreurs
 */
function formulaires_editer_subdivision_verifier_dist($id_subdivision = 'new', $id_parent = 0, $retour = '', $lier_trad = 0, $config_fonc = '', $row = array(), $hidden = '') {
	$erreurs = array();

	//$erreurs = formulaires_editer_objet_verifier('subdivision', $id_subdivision, array('id_subdivision', 'titre'));

	return $erreurs;
}

/**
 * Traitement du formulaire d'édition de subdivision
 *
 * Traiter les champs postés
 *
 * @uses formulaires_editer_objet_traiter()
 *
 * @param int|string $id_subdivision
 *     Identifiant de la subdivision. 'new' pour un nouveau paiement.
 * @param int $id_parent
 *     Identifiant de l'objet parent (si connu) - ici inutile
 * @param string $retour
 *     URL de redirection après le traitement
 * @param int $lier_trad
 *     Identifiant éventuel d'une nouvelle subdivision source d'une traduction (inutile nous sommes en multi)
 * @param string $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array $row
 *     Valeurs de la ligne SQL du paiement, si connu
 * @param string $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 * @return array
 *     Retours des traitements
 */
function formulaires_editer_subdivision_traiter_dist($id_subdivision = 'new', $id_parent = 0, $retour = '', $lier_trad = 0, $config_fonc = '', $row = array(), $hidden = '') {
	//if (_request('id_subdivision')==0) // vous pouvez indiquer que vous ne voulez pas que l'auteur soit lié à la région.
		//set_request('id_auteur','');   // objet_inserer va chercher l'information en un _request('id_auteur')
		//voir si on ne met pas une config pour cela.
	$retours = formulaires_editer_objet_traiter('subdivision', $id_subdivision, $id_parent, $lier_trad, $retour, $config_fonc, $row, $hidden);
	return $retours;
}
